@@ -16,7 +16,8 @@ mcp <- function(...) {
         stop(sQuote("linfct"), " doesn't have a ", sQuote("names"), 
              " attribute")
 
-    classes <- sapply(linfct, function(x) inherits(x, "matrix") || inherits(x, "character"))
+    classes <- sapply(linfct, function(x) inherits(x, "matrix") || 
+                                          inherits(x, "character"))
 
     if (all(classes)) {
         class(linfct) <- "mcp"
