@@ -3,15 +3,23 @@
 plot.confint.glht <- function(x, ...) {
 
     xi <- x$confint
+    ### make sure one-sided intervals are drawn correctly
+    xrange <- c(min(xi[,"lwr"]), max(xi[, "upr"]))
+    if (!is.finite(xrange[1])) xrange[1] <- min(xi[,"Estimate"])
+    if (!is.finite(xrange[2])) xrange[2] <- max(xi[,"Estimate"])
     yvals <- nrow(xi):1
     plot(c(xi[, "lwr"], xi[, "upr"]), rep.int(yvals, 2), 
-         type = "n", axes = FALSE, xlab = "", ylab = "", ...)
+         type = "n", axes = FALSE, xlab = "", ylab = "", xlim = xrange, ...)
     axis(1, ...)
     axis(2, at = nrow(xi):1, labels = dimnames(xi)[[1]], 
          srt = 0, ...)
     abline(h = yvals, lty = 1, lwd = 0, col = "lightgray")
     abline(v = 0, lty = 2, lwd = 0, ...)
-    segments(xi[, "lwr"], yvals, xi[, "upr"], yvals, ...)
+    left <- xi[, "lwr"]
+    left[!is.finite(left)] <- xrange[1] * 2
+    right <- xi[, "upr"]
+    right[!is.finite(right)] <- xrange[2] * 2
+    segments(left, yvals, right, yvals, ...)
     points(xi[, "lwr"], yvals, pch = "(", ...)
     points(xi[, "upr"], yvals, pch = ")", ...)
     points(xi[, "Estimate"], yvals, pch = 20, ...)
@@ -20,3 +28,5 @@ plot.confint.glht <- function(x, ...) {
           xlab = "Linear Hypotheses")
     box()
 }
+
+plot.glht <- function(x, ...) plot(confint(x), ...)
